#!/usr/bin/perl -w
#
#
#  Author: Preslav Nakov, QCRI
#  
#  Description: Substitues English text with %%%%% and creates a dictionary of the substituted English phrases.
#
#  Last modified: March 14, 2012
#
#


use strict;
use utf8;


#####################
###   I/O FILES   ###
#####################

### Input files
use constant INPUT_FILE  => $ARGV[0];
use constant OUTPUT_FILE => INPUT_FILE . '.noEnglish';
use constant DICT_FILE   => INPUT_FILE . '.noEnglish.dictFile';


my %tokens = ();

open(INPUT, INPUT_FILE) or die 'Failed to open for reading ' . INPUT_FILE;
binmode(INPUT, ":utf8");

open(OUTPUT, '>' . OUTPUT_FILE) or die 'Failed to open for writing ' . OUTPUT_FILE;
binmode(OUTPUT, ":utf8");

open(DICT, '>' . DICT_FILE) or die 'Failed to open for writing ' . DICT_FILE;
binmode(DICT, ":utf8");

for (my $lineNo = 1; <INPUT>; $lineNo++) {
	while (s/([a-zA-Z][a-zA-Z0-9 ,\.%:;\"\'\`\(\)\!\?\@\#\$\&\-\=\<\>\/\\]*)/%%%%% /) {
		print DICT "$lineNo\t$1\n";
	}
	if (s/(ـــــــــــــــــــــــ)/%%%%%/) {
		print DICT "$lineNo\t$1\n";
	}
	print OUTPUT;
}

close(INPUT);
close(OUTPUT);
close(DICT);
